# bi1x

Utilities Caltech Bi 1x: The Great Ideas of Biology: Exploration through Experimentation


## Installation / Usage

To install use pip:

    pip install bi1x


Or clone the repo:

    git clone https://github.com/justinbois/bi1x.git
    python setup.py install
